noizu-ops
============================
Simple interactive chat-gpt console session
with markdown formatted output and ability to commands as needed. 

# Usage

## Single Line Query
```
$ noizu-ops "Simple Query
> "Answer to query"
```


## Interactive Session
```
$ noizu-ops --session "configure routing table"
> Hello I am help you with: "confugure routing table"
> Please describe your task?
? ...
> This will require many steps would you like me to spawn a screen session?
(y/N) ?
> Okay 
[ Response ]
? ! ls -lh
```


## Knowledge Base
